#!/usr/bin/env python3
"""
SPDX-License-Identifier: Apache-2.0
Copyright Contributors to the ODPi Egeria project.

Display the status of cataloged platforms and servers.
"""
import argparse
import os
import sys
import time

import rich.box as box
from rich import print
from rich.console import Console
from rich.markdown import Markdown
from rich.panel import Panel
from rich.prompt import Prompt
from rich.table import Table

from pyegeria import (
    AutomatedCuration,
    PyegeriaException,
    print_basic_exception,
    settings,
    config_logging
)

EGERIA_USER = os.environ.get("EGERIA_USER", "erinoverview")
EGERIA_USER_PASSWORD = os.environ.get("EGERIA_USER_PASSWORD", "secret")

app_config = settings.Environment
config_logging()

def list_tech_elements(
    tech_name: str,
    server_name: str,
    platform_url: str,
    user: str,
    user_pass: str,
    jupyter: bool = app_config.egeria_jupyter,
    width: int = app_config.console_width,
):
    console = Console(width=width, force_terminal=not jupyter)

    a_client = AutomatedCuration(server_name, platform_url, user_id=user)
    token = a_client.create_egeria_bearer_token(user, user_pass)

    def build_classifications(classification: dict) -> Markdown:
        class_md = "\n"
        for c in classification:
            c_type = c["classificationName"]
            if c_type == "Anchors":
                continue
            class_md += f"* Classification: {c_type}\n"
            class_props = c.get("classificationProperties", None)
            if class_props is None:
                continue
            for prop in class_props.keys():
                class_md += f"\t* {prop}: {class_props[prop]}\n"
        if class_md == "-":
            output = None
        else:
            output = class_md
        return output

    def generate_table() -> Table:
        """Make a new table."""
        table = Table(
            title=f"Tech Type Elements for {tech_name} @ {time.asctime()}",
            caption=f"{platform_url} - {server_name} @ {time.asctime()}",
            style="bold bright_white on black",
            row_styles=["bold bright_white on black"],
            header_style="white on dark_blue",
            title_style="bold bright_white on black",
            caption_style="white on black",
            show_lines=True,
            box=box.ROUNDED,
            expand=True,
        )

        table.add_column("Qualified Name/GUID", width=38, no_wrap=True)
        table.add_column("Properties", width=40)
        table.add_column("Classifications", width=50)

        tech_elements = a_client.get_technology_type_elements(tech_name, get_templates=False, output_format="JSON",
                                                              report_spec="Tech-Type-Elements")
        if type(tech_elements) is str:
            console.print(f"No elements found for {tech_name}")
            sys.exit(1)

        note: str = " "
        for element in tech_elements:
            header = element["elementHeader"]
            tech_type = header["type"]["typeName"]
            tech_collection = header["origin"]["homeMetadataCollectionName"]
            tech_created_by = header["versions"]["createdBy"]
            tech_created_at = header["versions"]["createTime"]
            tech_guid = header["guid"]
            tech_classifications = header["otherClassifications"]
            class_md = build_classifications(tech_classifications)

            referenceables = element["properties"]
            tech_qualified_name = referenceables["qualifiedName"]
            extended = referenceables["extendedProperties"]
            ex_md: str = ""
            for key, value in extended.items():
                ex_md += f"* {key}: {value}\n"

            note = (
                f"{ex_md}\n"
                f"* Created by: {tech_created_by}\n"
                f"* Created at: {tech_created_at}\n"
                f"* Home Collection: {tech_collection}\n"
            )

            interfaces = extended.get("connectorInterfaces", None)
            if interfaces is not None:
                interface_type_name = interfaces["typeName"]
                interface_array_cnt = interfaces["arrayCount"]
                note += f"* Interface Type: {interface_type_name}\n"
                for i in range(0, int(interface_array_cnt)):
                    note += (
                        f"\t* Type: {interfaces['arrayValues']['propertyValueMap'][str(i)]['typeName']}"
                        f"\tName: {interfaces['arrayValues']['propertiesAsStrings'][str(i)]}\n"
                    )
            note_md = Markdown(note)
            qn = Markdown(f"\n{tech_qualified_name}\n \n--- \n\n\n{tech_guid}")
            cm = Markdown(class_md)
            table.add_row(qn, note_md, cm)
        return table

    try:
        console = Console(width=width, force_terminal=not jupyter)

        with console.pager(styles=True):
            console.print(generate_table())

    except PyegeriaException as e:
        print_basic_exception(e)
        print("\n\nPerhaps the type name isn't known")
    except Exception as e:
        console.print(e)

    finally:
        a_client.close_session()


def main():
    parser = argparse.ArgumentParser()

    parser.add_argument("--server", help="Name of the server to display status for")
    parser.add_argument("--url", help="URL Platform to connect to")
    parser.add_argument("--userid", help="User Id")
    parser.add_argument("--password", help="User Password")
    args = parser.parse_args()

    server = args.server if args.server is not None else app_config.egeria_view_server
    url = args.url if args.url is not None else app_config.egeria_view_server_url
    userid = args.userid if args.userid is not None else EGERIA_USER
    user_pass = args.password if args.password is not None else EGERIA_USER_PASSWORD
    try:
        tech_name = Prompt.ask(
            "Enter the tech type to view:", default="PostgreSQL Server"
        )
        list_tech_elements(tech_name, server, url, userid, user_pass)
    except KeyboardInterrupt:
        pass
    except Exception as e:
        print(f"An error occurred: {e}")


if __name__ == "__main__":
    main()



# Auto-generated by gen_report_specs.py
from pyegeria._output_format_models import Column, Format, ActionParameter, FormatSet, FormatSetDict

generated_format_sets = FormatSetDict({
    'Agreement-DrE': FormatSet(target_type='Agreement', heading='Agreement-DrE Attributes', description='Auto-generated format for Agreement (Create).', family='Digital Product Manager', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description'), Column(name='Identifier', key='agreement_identifier'), Column(name='Agreement Actors', key='agreement_actors')])], action=ActionParameter(function='CollectionManager.find_collections', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['Agreement']})),
    'Business-Imperative-DrE': FormatSet(target_type='Business Imperative', heading='Business-Imperative-DrE Attributes', description='Auto-generated format for Business Imperative (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Identifier', key='identifier'), Column(name='Usage', key='usage'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['GovernanceDriver']})),
    'Campaign-DrE': FormatSet(target_type='Campaign', heading='Campaign-DrE Attributes', description='Auto-generated format for Campaign (Create).', family='Project', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description'), Column(name='Project Type', key='project_type'), Column(name='Identifier', key='project_identifier'), Column(name='Mission', key='mission'), Column(name='Purposes', key='purposes'), Column(name='Start Date', key='start_date'), Column(name='Planned End Date', key='end_date'), Column(name='Priority', key='priority'), Column(name='Project Phase', key='project_phase'), Column(name='Project Status', key='project_status'), Column(name='Project Health', key='project_health')])], action=ActionParameter(function='ProjectManager.find_projects', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'classification_names': ['Campaign']})),
    'Certification-Type-DrE': FormatSet(target_type='Certification Type', heading='Certification-Type-DrE Attributes', description='Auto-generated format for Certification Type (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Document Identifier', key='document_identifier'), Column(name='Scope', key='scope'), Column(name='Usage', key='usage'), Column(name='Importance', key='importance'), Column(name='Details', key='details'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results'), Column(name='Restrictions', key='restrictions'), Column(name='Obligations', key='obligations'), Column(name='Entitlements', key='Entitlements')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['CertificationType']})),
    'Collection-DrE': FormatSet(target_type='Collection', heading='Collection-DrE Attributes', description='Auto-generated format for Collection (Create).', family='Digital Product Manager', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description')])], action=ActionParameter(function='CollectionManager.find_collections', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'])),
    'Comment-DrE': FormatSet(target_type='Comment', heading='Comment-DrE Attributes', description='Auto-generated format for Comment (Create).', family='Feedback Manager', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Associated Element', key='associated_element'), Column(name='Comment Text', key='comment_text'), Column(name='Comment Type', key='comment_type')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'])),
    'CSV-File-DrE': FormatSet(target_type='CSV File', heading='CSV-File-DrE Attributes', description='Auto-generated format for CSV File (Create).', family='Digital Product Manager', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description'), Column(name='File Path', key='file_path'), Column(name='File Encoding', key='file_encoding'), Column(name='File Extension', key='file_extension'), Column(name='File System Name', key='file_system_name')])]),
    'Data-Class-DrE': FormatSet(target_type='Data Class', heading='Data-Class-DrE Attributes', description='Auto-generated format for Data Class (Create).', family='Data Designer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description'), Column(name='Namespace', key='namespace'), Column(name='Match Property Names', key='match_property_names'), Column(name='Match Threshold', key='match_threshold'), Column(name='IsCaseSensitive', key='is_case_sensitive'), Column(name='Data Type', key='data_type'), Column(name='Allow Duplicate Values', key='duplicates_allowed'), Column(name='isNullable', key='is_nullable'), Column(name='Default Value', key='default_value'), Column(name='Average Value', key='avg_value'), Column(name='Value List', key='value_list'), Column(name='Value Range From', key='value_range_from'), Column(name='Value Range To', key='value_range_to'), Column(name='Sample Values', key='sample_values'), Column(name='Data Patterns', key='data_patterns'), Column(name='In Data Dictionary', key='in_data_dictionary'), Column(name='Containing Data Class', key='containing_data_class'), Column(name='Specializes Data Class', key='specializes_data_class')])], action=ActionParameter(function='DataDesigner.find_data_classes', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'])),
    'Data-Dictionary-DrE': FormatSet(target_type='Data Dictionary', heading='Data-Dictionary-DrE Attributes', description='Auto-generated format for Data Dictionary (Create).', family='Data Designer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description')])], action=ActionParameter(function='CollectionManager.find_collections', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['DataDictionary']})),
    'Data-Field-DrE': FormatSet(target_type='Data Field', heading='Data-Field-DrE Attributes', description='Auto-generated format for Data Field (Create).', family='Data Designer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description'), Column(name='Data Type', key='data_type'), Column(name='Position', key='position'), Column(name='Minimum Cardinality', key='min_cardinality'), Column(name='Maximum Cardinality', key='max_cardinality'), Column(name='In Data Structure', key='in_data_structure'), Column(name='In Data Dictionary', key='in_data_dictionary'), Column(name='Data Class', key='data_class'), Column(name='isNullable', key='is_nullable'), Column(name='Minimum Length', key='min_length'), Column(name='Length', key='length'), Column(name='Precision', key='precision'), Column(name='Ordered Values', key='ordered_values'), Column(name='Units', key='units'), Column(name='Default Value', key='default_value')])], action=ActionParameter(function='DataDesigner.find_data_fields', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'])),
    'Data-Processing-Purpose-DrE': FormatSet(target_type='Data Processing Purpose', heading='Data-Processing-Purpose-DrE Attributes', description='Auto-generated format for Data Processing Purpose (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Identifier', key='identifier'), Column(name='Usage', key='usage'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['DataProcessingPurpose']})),
    'Data-Sharing-Agreement-DrE': FormatSet(target_type='Data Sharing Agreement', heading='Data-Sharing-Agreement-DrE Attributes', description='Auto-generated format for Data Sharing Agreement (Create).', family='Digital Product Manager', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description'), Column(name='Identifier', key='identifier'), Column(name='Product Manager', key='product_manager')])], action=ActionParameter(function='CollectionManager.find_collections', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'classification_names': ['DataSharingAgreement']})),
    'Data-Specification-DrE': FormatSet(target_type='Data Specification', heading='Data-Specification-DrE Attributes', description='Auto-generated format for Data Specification (Create).', family='Data Designer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description')])], action=ActionParameter(function='CollectionManager.find_collections', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['DataSpec']})),
    'Data-Structure-DrE': FormatSet(target_type='Data Structure', heading='Data-Structure-DrE Attributes', description='Auto-generated format for Data Structure (Create).', family='Data Designer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description'), Column(name='In Data Specification', key='in_data_spec'), Column(name='In Data Dictionary', key='in_data_dictionary')])], action=ActionParameter(function='DataDesigner.find_data_structures', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'])),
    'Digital-Product-Catalog-DrE': FormatSet(target_type='Digital Product Catalog', heading='Digital-Product-Catalog-DrE Attributes', description='Auto-generated format for Digital Product Catalog (Create).', family='Digital Product Manager', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description')])], action=ActionParameter(function='CollectionManager.find_collections', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['DigitalProductCatalog']})),
    'Digital-Product-DrE': FormatSet(target_type='Digital Product', heading='Digital-Product-DrE Attributes', description='Auto-generated format for Digital Product (Create).', family='Digital Product Manager', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description'), Column(name='Product Name', key='product_name'), Column(name='Identifier', key='identifier'), Column(name='Maturity', key='maturity'), Column(name='Service Life', key='service_life'), Column(name='Introduction Date', key='introduction_date'), Column(name='Next Version Date', key='next_version_date'), Column(name='Withdrawal Date', key='withdrawal_date'), Column(name='Product Manager', key='product_manager'), Column(name='Agreements', key='agreements')])], action=ActionParameter(function='CollectionManager.find_collections', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['DigitalProduct']})),
    'Digital-Subscription-DrE': FormatSet(target_type='Digital Subscription', heading='Digital-Subscription-DrE Attributes', description='Auto-generated format for Digital Subscription (Create).', family='Digital Product Manager', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description'), Column(name='Identifier', key='identifier'), Column(name='Support Level', key='support_level'), Column(name='Service Levels', key='service_levels')])], action=ActionParameter(function='CollectionManager.find_collections', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['DigitalSubscription']})),
    'External-Data-Source-DrE': FormatSet(target_type='External Data Source', heading='External-Data-Source-DrE Attributes', description='Auto-generated format for External Data Source (Create).', family='External Reference', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description'), Column(name='Reference Title', key='reference_title'), Column(name='Reference Abstract', key='reference_abstract'), Column(name='Authors', key='authors'), Column(name='Organization', key='organization'), Column(name='Sources', key='reference_sources'), Column(name='License', key='license'), Column(name='Copyright', key='copyright'), Column(name='Attribution', key='category')])], action=ActionParameter(function='ExternalReference.find_external_references', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['ExternalDataSource']})),
    'External-Reference-DrE': FormatSet(target_type='External Reference', heading='External-Reference-DrE Attributes', description='Auto-generated format for External Reference (Create).', family='External Reference', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description'), Column(name='Reference Title', key='reference_title'), Column(name='Reference Abstract', key='reference_abstract'), Column(name='Authors', key='authors'), Column(name='Organization', key='organization'), Column(name='Sources', key='reference_sources'), Column(name='License', key='license'), Column(name='Copyright', key='copyright'), Column(name='Attribution', key='category'), Column(name='Number of Pages', key='number_of_pages'), Column(name='Page Range', key='page_range'), Column(name='Publication Series', key='publication_series'), Column(name='Publication Series Volume', key='pub_series_volume'), Column(name='Publisher', key='publisher'), Column(name='First Publication Date', key='first_pub_date'), Column(name='Publication Date', key='pub_date'), Column(name='Publication City', key='pub_city'), Column(name='Publication Year', key='pub_year'), Column(name='Publication Numbers', key='pub_numbers')])], action=ActionParameter(function='ExternalReference.find_external_references', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['CitedDocument']})),
    'Glossary-DrE': FormatSet(target_type='Glossary', heading='Glossary-DrE Attributes', description='Auto-generated format for Glossary (Create).', family='Glossary', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description'), Column(name='Language', key='language')])], action=ActionParameter(function='CollectionManager.find_collections', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['Glossary']})),
    'Glossary-Term-DrE': FormatSet(target_type='Glossary Term', heading='Glossary-Term-DrE Attributes', description='Auto-generated format for Glossary Term (Create).', family='Glossary', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='term_name'), Column(name='Glossary', key='glossary_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Folders', key='folders'), Column(name='Abbreviation', key='abbreviation'), Column(name='Example', key='example'), Column(name='Usage', key='usage')])], action=ActionParameter(function='GlossaryManager.find_glossary_terms', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'])),
    'Governance-Action-DrE': FormatSet(target_type='Governance Action', heading='Governance-Action-DrE Attributes', description='Auto-generated format for Governance Action (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Identifier', key='identifier'), Column(name='Usage', key='usage'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['GovernanceAction']})),
    'Governance-Approach-DrE': FormatSet(target_type='Governance Approach', heading='Governance-Approach-DrE Attributes', description='Auto-generated format for Governance Approach (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Identifier', key='identifier'), Column(name='Usage', key='usage'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['GovernanceApproach']})),
    'Governance-Control-DrE': FormatSet(target_type='Governance Control', heading='Governance-Control-DrE Attributes', description='Auto-generated format for Governance Control (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Identifier', key='identifier'), Column(name='Usage', key='usage'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='measurement', key='measurement'), Column(name='target', key='target'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['GovernanceMetric']})),
    'Governance-Driver-DrE': FormatSet(target_type='Governance Driver', heading='Governance-Driver-DrE Attributes', description='Auto-generated format for Governance Driver (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Usage', key='usage'), Column(name='Summary', key='summary'), Column(name='Scope', key='scope'), Column(name='Results', key='results'), Column(name='Outcomes', key='outcomes'), Column(name='Importance', key='importance'), Column(name='Implications', key='implications'), Column(name='Identifier', key='identifier')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['GovernanceDriver']})),
    'Governance-Obligation-DrE': FormatSet(target_type='Governance Obligation', heading='Governance-Obligation-DrE Attributes', description='Auto-generated format for Governance Obligation (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Identifier', key='identifier'), Column(name='Usage', key='usage'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['GovernanceObligation']})),
    'Governance-Policy-DrE': FormatSet(target_type='Governance Policy', heading='Governance-Policy-DrE Attributes', description='Auto-generated format for Governance Policy (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Identifier', key='identifier'), Column(name='Usage', key='usage'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['GovernancePolicy']})),
    'Governance-Principle-DrE': FormatSet(target_type='Governance Principle', heading='Governance-Principle-DrE Attributes', description='Auto-generated format for Governance Principle (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Identifier', key='identifier'), Column(name='Usage', key='usage'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['GovernancePrinciple']})),
    'Governance-Procedure-DrE': FormatSet(target_type='Governance Procedure', heading='Governance-Procedure-DrE Attributes', description='Auto-generated format for Governance Procedure (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Document Identifier', key='document_identifier'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='Implementation Description', key='implementation_description'), Column(name='Supports Policies', key='supports_policies'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['GovernanceProcedure']})),
    'Governance-Responsibility-DrE': FormatSet(target_type='Governance Responsibility', heading='Governance-Responsibility-DrE Attributes', description='Auto-generated format for Governance Responsibility (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Document Identifier', key='document_identifier'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='Implementation Description', key='implementation_description'), Column(name='Supports Policies', key='supports_policies'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['GovernanceResponsibility']})),
    'Governance-Rule-DrE': FormatSet(target_type='Governance Rule', heading='Governance-Rule-DrE Attributes', description='Auto-generated format for Governance Rule (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Document Identifier', key='document_identifier'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='Implementation Description', key='implementation_description'), Column(name='Supports Policies', key='supports_policies'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['GovernanceRule']})),
    'Governance-Strategy-DrE': FormatSet(target_type='Governance Strategy', heading='Governance-Strategy-DrE Attributes', description='Auto-generated format for Governance Strategy (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Identifier', key='identifier'), Column(name='Usage', key='usage'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['GovernanceStrategy']})),
    'Informal-Tag-DrE': FormatSet(target_type='Informal Tag', heading='Informal-Tag-DrE Attributes', description='Auto-generated format for Informal Tag (Create).', family='Feedback Manager', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description')])], action=ActionParameter(function='Client2.find_tags', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'])),
    'Information-Supply-Chain-DrE': FormatSet(target_type='Information Supply Chain', heading='Information-Supply-Chain-DrE Attributes', description='Auto-generated format for Information Supply Chain (Create).', family='Solution Architect', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description'), Column(name='Scope', key='scope'), Column(name='Purposes', key='purposes'), Column(name='Nested Information Supply Chains', key='nested_info_supply_chains'), Column(name='In Information Supply Chain', key='in_supply_chain')])], action=ActionParameter(function='SolutionArchitect.find_information_supply_chains', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'])),
    'License-Type-DrE': FormatSet(target_type='License Type', heading='License-Type-DrE Attributes', description='Auto-generated format for License Type (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Document Identifier', key='document_identifier'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Summary', key='summary'), Column(name='Scope', key='scope'), Column(name='Usage', key='usage'), Column(name='Importance', key='importance'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results'), Column(name='Description', key='description'), Column(name='Details', key='details'), Column(name='Restrictions', key='restrictions'), Column(name='Obligations', key='obligations'), Column(name='Entitlements', key='Entitlements')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'])),
    'Naming-Standard-Rule-DrE': FormatSet(target_type='Naming Standard Rule', heading='Naming-Standard-Rule-DrE Attributes', description='Auto-generated format for Naming Standard Rule (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Document Identifier', key='document_identifier'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='Implementation Description', key='implementation_description'), Column(name='Supports Policies', key='supports_policies'), Column(name='Name Patterns', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['NamingStandardRule']})),
    'NoteLog-DrE': FormatSet(target_type='NoteLog', heading='NoteLog-DrE Attributes', description='Auto-generated format for NoteLog (Create).', family='Feedback Manager', formats=[Format(types=['ALL'], columns=[Column(name='Journal Name', key='display_name'), Column(name='Associated Element', key='associated_element'), Column(name='Journal Description', key='journal_description'), Column(name='Note Entry', key='note_entry')])], action=ActionParameter(function='Client2.find_notes', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'])),
    'Personal-Project-DrE': FormatSet(target_type='Personal Project', heading='Personal-Project-DrE Attributes', description='Auto-generated format for Personal Project (Create).', family='Project', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description'), Column(name='Project Type', key='project_type'), Column(name='Identifier', key='project_identifier'), Column(name='Mission', key='mission'), Column(name='Purposes', key='purposes'), Column(name='Start Date', key='start_date'), Column(name='Planned End Date', key='end_date'), Column(name='Priority', key='priority'), Column(name='Project Phase', key='project_phase'), Column(name='Project Status', key='project_status'), Column(name='Project Health', key='project_health')])], action=ActionParameter(function='ProjectManager.find_projects', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'classification_names': ['PersonalProject']})),
    'Project-DrE': FormatSet(target_type='Project', heading='Project-DrE Attributes', description='Auto-generated format for Project (Create).', family='Project', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description'), Column(name='Project Type', key='project_type'), Column(name='Identifier', key='project_identifier'), Column(name='Mission', key='mission'), Column(name='Purposes', key='purposes'), Column(name='Start Date', key='start_date'), Column(name='Planned End Date', key='end_date'), Column(name='Priority', key='priority'), Column(name='Project Phase', key='project_phase'), Column(name='Project Status', key='project_status'), Column(name='Project Health', key='project_health')])], action=ActionParameter(function='ProjectManager.find_projects', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'])),
    'Regulation-Article-DrE': FormatSet(target_type='Regulation Article', heading='Regulation-Article-DrE Attributes', description='Auto-generated format for Regulation Article (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Identifier', key='identifier'), Column(name='Usage', key='usage'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['RegulationArticle']})),
    'Regulation-DrE': FormatSet(target_type='Regulation', heading='Regulation-DrE Attributes', description='Auto-generated format for Regulation (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Identifier', key='identifier'), Column(name='Usage', key='usage'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='Regulation Source', key='regulation_source'), Column(name='Regulators', key='regulators'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['Regulation']})),
    'Security-Access-Control-DrE': FormatSet(target_type='Security Access Control', heading='Security-Access-Control-DrE Attributes', description='Auto-generated format for Security Access Control (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Identifier', key='identifier'), Column(name='Usage', key='usage'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['SecurityAccessControl']})),
    'Security-Group-DrE': FormatSet(target_type='Security Group', heading='Security-Group-DrE Attributes', description='Auto-generated format for Security Group (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Identifier', key='identifier'), Column(name='Usage', key='usage'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['SEcurityGroup']})),
    'security_access_control-DrE': FormatSet(target_type='security_access_control', heading='security_access_control-DrE Attributes', description='Auto-generated format for security_access_control (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Identifier', key='identifier'), Column(name='Usage', key='usage'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='criteria', key='criteria'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['GovernanceZone']})),
    'Service-Level-Objectives-DrE': FormatSet(target_type='Service Level Objectives', heading='Service-Level-Objectives-DrE Attributes', description='Auto-generated format for Service Level Objectives (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Document Identifier', key='document_identifier'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='Implementation Description', key='implementation_description'), Column(name='Supports Policies', key='supports_policies'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['ServiceLevelObjectives']})),
    'Solution-Blueprint-DrE': FormatSet(target_type='Solution Blueprint', heading='Solution-Blueprint-DrE Attributes', description='Auto-generated format for Solution Blueprint (Create).', family='Solution Architect', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description'), Column(name='Solution Components', key='solution_components')])], action=ActionParameter(function='SolutionArchitect.find_solution_blueprints', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'])),
    'Solution-Component-DrE': FormatSet(target_type='Solution Component', heading='Solution-Component-DrE Attributes', description='Auto-generated format for Solution Component (Create).', family='Solution Architect', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description'), Column(name='Solution Component Type', key='soln_comp_type'), Column(name='Planned Deployed Implementation Type', key='planned_deployed_impl_type'), Column(name='In Solution Components', key='in_components'), Column(name='In Solution Blueprints', key='solution_blueprints'), Column(name='In Information Supply Chains', key='in_supply_chains'), Column(name='Actors', key='actors')])], action=ActionParameter(function='SolutionArchitect.find_solution_components', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'])),
    'Solution-Role-DrE': FormatSet(target_type='Solution Role', heading='Solution-Role-DrE Attributes', description='Auto-generated format for Solution Role (Create).', family='Solution Architect', formats=[Format(types=['ALL'], columns=[Column(name='Name', key='name'), Column(name='Description', key='description'), Column(name='Title', key='title'), Column(name='Scope', key='scope'), Column(name='identifier', key='identifier'), Column(name='Domain Identifier', key='domain_identifier')])], action=ActionParameter(function='SolutionArchitect.find_solution_roles', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'])),
    'Study-Project-DrE': FormatSet(target_type='Study Project', heading='Study-Project-DrE Attributes', description='Auto-generated format for Study Project (Create).', family='Project', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description'), Column(name='Project Type', key='project_type'), Column(name='Identifier', key='project_identifier'), Column(name='Mission', key='mission'), Column(name='Purposes', key='purposes'), Column(name='Start Date', key='start_date'), Column(name='Planned End Date', key='end_date'), Column(name='Priority', key='priority'), Column(name='Project Phase', key='project_phase'), Column(name='Project Status', key='project_status'), Column(name='Project Health', key='project_health')])], action=ActionParameter(function='ProjectManager.find_projects', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'classification_names': ['StudyProject']})),
    'Task-DrE': FormatSet(target_type='Task', heading='Task-DrE Attributes', description='Auto-generated format for Task (Create).', family='Project', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Description', key='description'), Column(name='Project Type', key='project_type'), Column(name='Identifier', key='project_identifier'), Column(name='Mission', key='mission'), Column(name='Purposes', key='purposes'), Column(name='Start Date', key='start_date'), Column(name='Planned End Date', key='end_date'), Column(name='Priority', key='priority'), Column(name='Project Phase', key='project_phase'), Column(name='Project Status', key='project_status'), Column(name='Project Health', key='project_health')])], action=ActionParameter(function='ProjectManager.find_projects', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'classification_names': ['Task']})),
    'Threat-Definition-DrE': FormatSet(target_type='Threat Definition', heading='Threat-Definition-DrE Attributes', description='Auto-generated format for Threat Definition (Create).', family='Governance Officer', formats=[Format(types=['ALL'], columns=[Column(name='Display Name', key='display_name'), Column(name='Summary', key='summary'), Column(name='Description', key='description'), Column(name='Domain Identifier', key='domain_identifier'), Column(name='Identifier', key='identifier'), Column(name='Usage', key='usage'), Column(name='Scope', key='scope'), Column(name='Importance', key='importance'), Column(name='Implications', key='implications'), Column(name='Outcomes', key='outcomes'), Column(name='Results', key='results')])], action=ActionParameter(function='GovernanceOfficer.find_governance_definitions', required_params=['search_string'], optional_params=['page_size', 'start_from', 'starts_with', 'ends_with', 'ignore_case'], spec_params={'metadata_element_types': ['ThreatDefinition']}))
})



#!/usr/bin/env python3
"""
SPDX-License-Identifier: Apache-2.0
Copyright Contributors to the ODPi Egeria project.



List catalog targets

"""
import argparse
import os
import sys
import time

from rich import box
from rich.console import Console
from rich.markdown import Markdown
from rich.prompt import Prompt
from rich.table import Table


from pyegeria import (
    EgeriaTech,
    PyegeriaException,
    print_basic_exception,
    settings,
    config_logging
)

EGERIA_USER = os.environ.get("EGERIA_USER", "erinoverview")
EGERIA_USER_PASSWORD = os.environ.get("EGERIA_USER_PASSWORD", "secret")

app_config = settings.Environment
config_logging()
console = Console(width = app_config.console_width)


def display_catalog_targets(
    connector: str,
    view_server: str = app_config.egeria_view_server,
    view_url: str = app_config.egeria_view_server_url,
    user: str = EGERIA_USER,
    user_pass: str = EGERIA_USER_PASSWORD,
    paging: bool = True,
    jupyter: bool = app_config.egeria_jupyter,
    width: int = app_config.console_width,
):
    """Display catalog targets for the specified connector as a table.

    Parameters
    ----------
    connector : str
        The connector to retrieve catalog targets for.
    view_server : str
        The Egeria view server name.
    view_url : str
        The URL for the Egeria view server.
    user : str
        The user name for authenticating with the Egeria server.
    user_pass : str
        The user password for authenticating with the Egeria server.
    paging : bool, default is True
        Whether to enable paging mode when displaying the table.
    jupyter : bool
        Indicates if the environment is a Jupyter notebook.
    width : int
        The width of the console for table printing.
    """
    console = Console(force_terminal=not jupyter, width=width, soft_wrap=True)

    def generate_table() -> Table:
        """Make a new table."""
        table = Table(
            title=f"All Catalog Targets for Integration Connector {connector} @ {time.asctime()}",
            style="bold white on black",
            row_styles=["bold white on black"],
            header_style="white on dark_blue",
            title_style="bold white on black",
            show_lines=True,
            box=box.ROUNDED,
            caption=f"Catalog Targets for '{view_server}' @ Platform - {view_url}",
            expand=True,
        )
        table.add_column("Name of Target")
        table.add_column("Catalog Target")

        # table.add_column("Relationship GUID", no_wrap=True)
        table.add_column("Configuration Properties")
        table.add_column("Template Properties")
        table.add_column("Operational Instructions", max_width=20)
        # table.add_column("Delete Method")

        if type(cat_targets) is list:
            for target in cat_targets:
                target_name = target['properties'].get("catalogTargetName", "---")
                target_source = target.get("metadataSourceQualifiedName", "---")
                target_rel = target.get("relationshipGUID", "---")
                target_sync = target.get("permittedSynchronization")
                target_delete = target.get("deleteMethod", "---")
                op_instruct = f"* {target_sync}\n* {target_delete}"
                op_instruct_out = Markdown(op_instruct)
                # target_guid = target['catalogTargetElement']['guid']
                connector_unique = target["catalogTargetElement"]["uniqueName"]

                cat_target_out = Markdown(
                    f"* Target Name: {target_name}\n* Target Source: {target_source}\n"
                    f"* Relationship Guid: {target_rel}"
                )

                config_props = target.get("configurationProperties", "---")
                if type(config_props) is dict:
                    config_props_md = ""
                    for prop in config_props:
                        config_props_md += f"* {prop}: {config_props[prop]}\n"
                    config_props_out = Markdown(config_props_md)
                else:
                    config_props_out = "---"

                template_props = target.get("templateProperties", "---")
                if type(template_props) is dict:
                    template_props_md = ""
                    for prop in template_props:
                        template_props_md += f"* {prop}: {template_props[prop]}\n"
                    template_props_out = Markdown(template_props_md)
                else:
                    template_props_out = "---"

                table.add_row(
                    connector_unique,
                    cat_target_out,
                    config_props_out,
                    template_props_out,
                    op_instruct_out,
                )

        return table

    try:
        a_client = EgeriaTech(view_server, view_url, user)
        token = a_client.create_egeria_bearer_token(user, user_pass)
        connector = connector.strip()


        connector_guid = a_client.get_connector_guid(connector)
        if connector_guid is None or connector_guid == "No connector found":
            console.print(f"\n\n===> No connector found with name '{connector}'\n\n")
            sys.exit(1)

        cat_targets = a_client.get_catalog_targets(connector_guid)
        console = Console(force_terminal=not jupyter, width=width, soft_wrap=True)
        with console.pager(styles=True):
            console.print(generate_table(), soft_wrap=True)


    except PyegeriaException as e:
        print(f"\n\n===> Perhaps integration connector {connector} is not known?\n\n")
        print_basic_exception(e)
    except (
        Exception
    ) as e:
        console.print_exception()
    finally:
        a_client.close_session()


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("--server", help="Name of the server to display status for")
    parser.add_argument("--url", help="URL Platform to connect to")
    parser.add_argument("--userid", help="User Id")
    parser.add_argument("--password", help="User Password")
    parser.add_argument("--jupyter", help="Enable for Jupyter terminal compatibility")
    parser.add_argument("--width", help="Screen width, in characters, to use")

    args = parser.parse_args()

    server = args.server if args.server is not None else app_config.egeria_view_server
    url = args.url if args.url is not None else app_config.egeria_view_server_url
    userid = args.userid if args.userid is not None else EGERIA_USER
    user_pass = args.password if args.password is not None else EGERIA_USER_PASSWORD
    jupyter = args.jupyter if args.jupyter is not None else app_config.egeria_jupyter
    width = args.width if args.width is not None else app_config.console_width

    try:
        connector = Prompt.ask(
            "Enter the Integration Connector to list catalog targets for"
        ).strip()
        display_catalog_targets(connector, server, url, userid, user_pass, jupyter, width=width)

    except KeyboardInterrupt:
        pass


if __name__ == "__main__":
    main()



#!/usr/bin/env python3
"""
SPDX-Lic
ense-Identifier: Apache-2.0
Copyright Contributors to the ODPi Egeria project.

Unit tests for the Utils helper functions using the Pytest framework.


A simple display for glossary terms
"""
import argparse
import json
import os

from rich import print
from rich.console import Console
from rich.panel import Panel
from rich.prompt import Prompt
from rich.text import Text
from rich.tree import Tree

from pyegeria import (
    ClassificationManager,
    Client,
    InvalidParameterException,
    PropertyServerException,
    UserNotAuthorizedException,
)

EGERIA_METADATA_STORE = os.environ.get("EGERIA_METADATA_STORE", "active-metadata-store")
EGERIA_KAFKA_ENDPOINT = os.environ.get("KAFKA_ENDPOINT", "localhost:9092")
EGERIA_PLATFORM_URL = os.environ.get("EGERIA_PLATFORM_URL", "https://localhost:9443")
EGERIA_VIEW_SERVER = os.environ.get("EGERIA_VIEW_SERVER", "view-server")
EGERIA_VIEW_SERVER_URL = os.environ.get(
    "EGERIA_VIEW_SERVER_URL", "https://localhost:9443"
)
EGERIA_INTEGRATION_DAEMON = os.environ.get("EGERIA_INTEGRATION_DAEMON", "integration-daemon")
EGERIA_ADMIN_USER = os.environ.get("ADMIN_USER", "garygeeke")
EGERIA_ADMIN_PASSWORD = os.environ.get("ADMIN_PASSWORD", "secret")
EGERIA_USER = os.environ.get("EGERIA_USER", "erinoverview")
EGERIA_USER_PASSWORD = os.environ.get("EGERIA_USER_PASSWORD", "secret")
EGERIA_JUPYTER = bool(os.environ.get("EGERIA_JUPYTER", "False"))
EGERIA_WIDTH = int(os.environ.get("EGERIA_WIDTH", "200"))


def display_guid(
    guid: str,
    server: str,
    url: str,
    username: str,
    user_password: str,
    jupyter: bool = EGERIA_JUPYTER,
    width: int = EGERIA_WIDTH,
):
    c = Client(server, url, user_id=username)
    url = (
        f"{url}/servers/{server}/open-metadata/repository-services/users/{username}/"
        f"instances/entity/{guid}"
    )
    # c =  ClassificationManager(server, url)

    bearer_token = c.create_egeria_bearer_token(username, user_password)

    try:
        console = Console(
            width=width, force_terminal=not jupyter, style="bold white on black"
        )
        r = c.make_request("GET", url)
        if r.status_code == 200:
            pass
        # r = c.retrieve_instance_for_guid(guid)
        e = r.json()["entity"]
        p = e["properties"]["instanceProperties"]

        type_name = Text(f"Type is: {e['type']['typeDefName']}")
        metadataCollection = Text(
            f"Metadadata Collection: {e['metadataCollectionName']}"
        )
        created = Text(f"Created at: {e['createTime']}")
        details = Text(f"Details: {json.dumps(p, indent=2)}")

        tree = Tree(
            f"{guid}",
            style="bold bright_white on black",
            guide_style="bold bright_blue",
        )

        tree = tree.add(type_name)
        tree.add(metadataCollection)
        tree.add(created)
        tree.add(Panel(details, title="Element Details", expand=False))
        print(tree)

        c.close_session()

    except (
        InvalidParameterException,
        PropertyServerException,
        UserNotAuthorizedException,
        ValueError,
    ) as e:
        if type(e) is str:
            console.print_exception()
        else:
            # console.print_exception(show_locals=True)
            console.print(f"\n ===> Looks like the GUID isn't known...\n")


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("--server", help="Name of the server to display status for")
    parser.add_argument("--url", help="URL Platform to connect to")
    parser.add_argument("--userid", help="User Id")
    parser.add_argument("--password", help="User Password")

    # parser.add_argument("--sponsor", help="Name of sponsor to search")
    args = parser.parse_args()

    server = args.server if args.server is not None else EGERIA_METADATA_STORE
    url = args.url if args.url is not None else EGERIA_PLATFORM_URL
    userid = args.userid if args.userid is not None else EGERIA_USER
    user_pass = args.password if args.password is not None else EGERIA_USER_PASSWORD

    try:
        guid = Prompt.ask("Enter the GUID to retrieve", default=None)
        display_guid(guid, server, url, userid, user_pass)
    except KeyboardInterrupt:
        pass


if __name__ == "__main__":
    main()
